@@ -596,7 +596,7 @@ tweak_metadata <- function(html, path) {
   if (nzchar(text)) {
     words <- unlist(strsplit(text, " "))
     no_char <- cumsum(unlist(lapply(words, function(x) {nchar(x) + 1})))
-    max_n <- max(which(no_char<= 197))
+    max_n <- max(which(no_char <= 197), 1)
     description_string <- paste(words[1: max_n], collapse = " ")
     if (max_n != length(words)) {
       description_string <- paste0(description_string, "...")
@@ -679,8 +679,10 @@ check_packages <- function(pkgs) {
 preview_book <- function(path = ".", output = "bookdown::bs4_book") {
   old <- setwd(path)
   on.exit(setwd(old))
-
-  render_book("index.Rmd",
+  if (is_empty(index <- get_index_file())) {
+    stop(sprintf('`index.Rmd` was not found in path = "%s".', path))
+  }
+  render_book(index,
     output_format = output,
     quiet = TRUE,
     clean = FALSE,
